@@ -1,5 +1,8 @@
 #' Return melted data for each token in a delimited file (including csv & tsv)
 #'
+#' `r lifecycle::badge("superseded")`
+#' This function has been superseded in readr and moved to the meltr package.
+#'
 #' For certain non-rectangular data formats, it can be useful to parse the data
 #' into a melted format where each row represents a single token.
 #'
@@ -52,6 +55,10 @@ melt_delim <- function(file, delim, quote = '"',
                        skip = 0, n_max = Inf,
                        progress = show_progress(),
                        skip_empty_rows = FALSE) {
+  if (!edition_first()) {
+    lifecycle::deprecate_soft("2.0.0", what = "melt_delim()", details = "Please use `meltr::melt_delim()` instead")
+  }
+
   if (!nzchar(delim)) {
     stop("`delim` must be at least one character, ",
       "use `melt_table()` for whitespace delimited input.", call. = FALSE)
@@ -72,6 +79,10 @@ melt_csv <- function(file, locale = default_locale(), na = c("", "NA"),
                      trim_ws = TRUE, skip = 0, n_max = Inf,
                      progress = show_progress(),
                      skip_empty_rows = FALSE) {
+  if (!edition_first()) {
+    lifecycle::deprecate_soft("2.0.0", what = "melt_csv()", details = "Please use `meltr::melt_csv()` instead")
+  }
+
   tokenizer <- tokenizer_csv(na = na, quoted_na = quoted_na, quote = quote,
     comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows)
   melt_delimited(file, tokenizer, locale = locale, skip = skip,
@@ -86,9 +97,12 @@ melt_csv2 <- function(file, locale = default_locale(), na = c("", "NA"),
                       trim_ws = TRUE, skip = 0, n_max = Inf,
                       progress = show_progress(),
                       skip_empty_rows = FALSE) {
+  if (!edition_first()) {
+    lifecycle::deprecate_soft("2.0.0", what = "melt_csv2()", details = "Please use `meltr::melt_csv2()` instead")
+  }
 
   if (locale$decimal_mark == ".") {
-    message("Using ',' as decimal and '.' as grouping mark. Use melt_delim() for more control.")
+    cli::cli_alert_info("Using {.val ','} as decimal and {.val '.'} as grouping mark. Use {.fn read_delim} for more control.")
     locale$decimal_mark <- ","
     locale$grouping_mark <- "."
   }
@@ -108,6 +122,10 @@ melt_tsv <- function(file, locale = default_locale(), na = c("", "NA"),
                      trim_ws = TRUE, skip = 0, n_max = Inf,
                      progress = show_progress(),
                      skip_empty_rows = FALSE) {
+  if (!edition_first()) {
+    lifecycle::deprecate_soft("2.0.0", what = "melt_tsv()", details = "Please use `meltr::melt_tsv()` instead")
+  }
+
   tokenizer <- tokenizer_tsv(na = na, quoted_na = quoted_na, quote = quote,
     comment = comment, trim_ws = trim_ws, skip_empty_rows = skip_empty_rows)
   melt_delimited(file, tokenizer, locale = locale, skip = skip,
@@ -148,8 +166,8 @@ melt_delimited <- function(file, tokenizer, locale = default_locale(),
     data <- datasource_connection(file, skip, skip_empty_rows = skip_empty_rows, comment)
   } else {
     if (empty_file(file)) {
-       return(tibble::data_frame(row = double(), col = double(),
-                                 data_type = character(), value = character()))
+       return(tibble::tibble(row = double(), col = double(),
+                             data_type = character(), value = character()))
     }
     if (is.character(file) && identical(locale$encoding, "UTF-8")) {
       # When locale is not set, file is probablly marked as its correct encoding.
