@@ -1,7 +1,8 @@
 #ifndef FASTREAD_TOKENIZER_LOG_H_
 #define FASTREAD_TOKENIZER_LOG_H_
 
-#include <Rcpp.h>
+#include "cpp11/protect.hpp"
+
 #include "Token.h"
 #include "Tokenizer.h"
 #include "utils.h"
@@ -20,11 +21,10 @@ class TokenizerLog : public Tokenizer {
   LogState state_;
   int row_, col_;
   bool moreTokens_;
+  bool trimWS_;
 
 public:
-
-  TokenizerLog() {
-  }
+  TokenizerLog(bool trimWS) : trimWS_(trimWS) {}
 
   void tokenize(SourceIterator begin, SourceIterator end) {
     cur_ = begin;
@@ -37,9 +37,9 @@ public:
     moreTokens_ = true;
   }
 
-  std::pair<double,size_t> progress() {
+  std::pair<double, size_t> progress() {
     size_t bytes = cur_ - begin_;
-    return std::make_pair(bytes / (double) (end_ - begin_), bytes);
+    return std::make_pair(bytes / (double)(end_ - begin_), bytes);
   }
 
   Token nextToken() {
@@ -55,17 +55,16 @@ public:
       Advance advance(&cur_);
 
       if ((row_ + 1) % 100000 == 0 || (col_ + 1) % 100000 == 0)
-        Rcpp::checkUserInterrupt();
+        cpp11::check_user_interrupt();
 
-      switch(state_) {
+      switch (state_) {
       case LOG_DELIM:
         if (*cur_ == '\r' || *cur_ == '\n') {
           newRecord();
           advanceForLF(&cur_, end_);
           return Token(TOKEN_EMPTY, row, col);
         } else if (*cur_ == ' ') {
-          newField();
-          return Token(TOKEN_EMPTY, row, col);
+          break;
         } else if (*cur_ == '"') {
           state_ = LOG_STRING;
         } else if (*cur_ == '[') {
@@ -91,8 +90,8 @@ public:
           return fieldToken(token_begin + 1, cur_ - 1, row, col);
         } else if (*cur_ == '\r' || *cur_ == '\n') {
           newRecord();
-          return fieldToken(token_begin + 1, advanceForLF(&cur_, end_) - 1,
-            row, col);
+          return fieldToken(
+              token_begin + 1, advanceForLF(&cur_, end_) - 1, row, col);
         } else {
           state_ = LOG_STRING;
         }
@@ -154,7 +153,6 @@ public:
   }
 
 private:
-
   void newField() {
     col_++;
     state_ = LOG_DELIM;
@@ -167,9 +165,15 @@ private:
   }
 
   Token fieldToken(SourceIterator begin, SourceIterator end, int row, int col) {
-    return Token(begin, end, row, col, false).flagNA(std::vector<std::string>(1, "-"));
-  }
+    Token t(begin, end, row, col, false);
+    if (trimWS_) {
+      t.trim();
+    }
 
+    t.flagNA(std::vector<std::string>(1, "-"));
+
+    return t;
+  }
 };
 
 #endif
