@@ -1,15 +1,15 @@
-#include <Rcpp.h>
-using namespace Rcpp;
+#include "cpp11/list.hpp"
+#include "cpp11/sexp.hpp"
+#include "cpp11/strings.hpp"
 
 #include "Collector.h"
 #include "LocaleInfo.h"
 #include "Token.h"
 
-// [[Rcpp::export]]
-RObject type_convert_col(
-    CharacterVector x,
-    List spec,
-    List locale_,
+[[cpp11::register]] cpp11::sexp type_convert_col(
+    const cpp11::strings& x,
+    const cpp11::list& spec,
+    const cpp11::list& locale_,
     int col,
     const std::vector<std::string>& na,
     bool trim_ws) {
@@ -27,13 +27,14 @@ RObject type_convert_col(
     } else {
       const char* begin = CHAR(string);
       t = Token(begin, begin + Rf_length(string), i - 1, col - 1, false);
-      if (trim_ws)
+      if (trim_ws) {
         t.trim();
+      }
       t.flagNA(na);
     }
 
     collector->setValue(i, t);
   }
 
-  return collector->vector();
+  return static_cast<SEXP>(collector->vector());
 }
